<?php

namespace Drupal\commerce_product_quantity\Utility;

/**
 * Trait for description.
 */
trait DescriptionTemplateTrait {

  /**
   * Generate a render array with our templated content.
   *
   * @return array
   *   A render array.
   */
  public function description($tem_name, $extra = "") {
    $template_path = $this->getDescriptionTemplatePath($tem_name);
    $template = file_get_contents($template_path);
    $build = [
      'description' => [
        '#type' => 'inline_template',
        '#template' => $template,
        '#context' => $this->getDescriptionVariables($tem_name, $extra),
      ],
    ];
    return $build;
  }

  /**
   * Name of our module.
   *
   * @return string
   *   A module name.
   */
  abstract protected function getModuleName();

  /**
   * Variables to act as context to the twig template file.
   *
   * @return array
   *   Associative array that defines context for a template.
   */
  protected function getDescriptionVariables($tem_name, $extra = "") {
    $variables['module'] = $this->getModuleName();
    return $variables;
  }

  /**
   * Get full path to the template.
   *
   * @return string
   *   Path string.
   */
  protected function getDescriptionTemplatePath($tem_name) {
    $config_path = \Drupal::service('extension.list.module')->getPath('commerce_product_quantity') . "/templates/$tem_name.html.twig";
    return $config_path;
  }

}
